==> ZenTaoALM.11.6.2.int.zip: zentaoalm/module/dev/lang/zh-cn.php <==
<?php
$lang->dev->common     = '二次开发';
$lang->dev->api        = 'API';
$lang->dev->db         = '数据库';
$lang->dev->editor     = '编辑器';
$lang->dev->dbList     = '数据库';
$lang->dev->moduleList = '模块列表';
$lang->dev->params     = '参数列表';
$lang->dev->type       = '类型';
$lang->dev->desc       = '描述';
$lang->dev->noParams   = '无参数';
$lang->dev->post       = 'POST参数';

$lang->dev->paramRange  = '取值范围：%s';
$lang->dev->paramDate   = '日期格式：YY-mm-dd，如：2019-01-01';
$lang->dev->paramColor  = '颜色格式：#RGB，如：#3da7f5';
$lang->dev->paramMailto = "填写帐号，多个账号用','分隔。";

$lang->dev->fields = array();
$lang->dev->fields['id']     = '序号';
$lang->dev->fields['name']   = '字段';
$lang->dev->fields['desc']   = '描述';
$lang->dev->fields['type']   = '类型';
$lang->dev->fields['length'] = '长度';
$lang->dev->fields['null']   = '是否可空';

$lang->dev->tableList = array();
$lang->dev->tableList['action']           = '系统日志';
$lang->dev->tableList['bug']              = 'Bug';
$lang->dev->tableList['build']            = '版本';
$lang->dev->tableList['burn']             = '燃尽图';
$lang->dev->tableList['case']             = '测试用例';
$lang->dev->tableList['casestep']         = '用例步骤';
$lang->dev->tableList['company']          = '公司';
$lang->dev->tableList['config']           = '配置';
$lang->dev->tableList['custom']           = '自定义';
$lang->dev->tableList['dept']             = '部门';
$lang->dev->tableList['doc']              = '文档';
$lang->dev->tableList['doclib']           = '文档库';
$lang->dev->tableList['effort']           = '日志';
$lang->dev->tableList['extension']        = '插件';
$lang->dev->tableList['file']             = '附件';
$lang->dev->tableList['group']            = '用户组';
$lang->dev->tableList['grouppriv']        = '组权限';
$lang->dev->tableList['history']          = '操作历史';
$lang->dev->tableList['lang']             = '语言定义';
$lang->dev->tableList['module']           = '模块';
$lang->dev->tableList['product']          = $lang->productCommon;
$lang->dev->tableList['productplan']      = $lang->productCommon . '计划';
$lang->dev->tableList['project']          = $lang->projectCommon;
$lang->dev->tableList['projectproduct']   = $lang->projectCommon . $lang->productCommon;
$lang->dev->tableList['projectstory']     = $lang->projectCommon . '需求';
$lang->dev->tableList['release']          = '发布';
$lang->dev->tableList['story']            = '需求';
$lang->dev->tableList['storyspec']        = '需求描述';
$lang->dev->tableList['task']             = '任务';
$lang->dev->tableList['taskestimate']     = '任务预计';
$lang->dev->tableList['team']             = '团队';
$lang->dev->tableList['testresult']       = '测试结果';
$lang->dev->tableList['testrun']          = '测试执行';
$lang->dev->tableList['testtask']         = '测试版本';
$lang->dev->tableList['todo']             = '待办';
$lang->dev->tableList['user']             = '用户';
$lang->dev->tableList['usercontact']      = '用户联系人';
$lang->dev->tableList['usergroup']        = '用户组';
$lang->dev->tableList['userquery']        = '用户查询';
$lang->dev->tableList['usertpl']          = '用户模板';
$lang->dev->tableList['admin']            = '后台管理';
$lang->dev->tableList['api']              = 'API接口';
$lang->dev->tableList['backup']           = '备份';
$lang->dev->tableList['common']           = '公有模块';
$lang->dev->tableList['convert']          = '导入';
$lang->dev->tableList['dev']              = '二次开发';
$lang->dev->tableList['editor']           = '编辑器';
$lang->dev->tableList['git']              = 'GIT';
$lang->dev->tableList['index']            = '首页';
$lang->dev->tableList['install']          = '安装';
$lang->dev->tableList['mail']             = '邮箱';
$lang->dev->tableList['misc']             = '杂项';
$lang->dev->tableList['my']               = '我的地盘';
$lang->dev->tableList['qa']               = '测试';
$lang->dev->tableList['report']           = '统计';
$lang->dev->tableList['search']           = '搜索';
$lang->dev->tableList['sso']              = '单点登录';
$lang->dev->tableList['svn']              = 'SVN';
$lang->dev->tableList['testcase']         = '测试用例';
$lang->dev->tableList['testreport']       = '测试报告';
$lang->dev->tableList['testsuite']        = '测试套件';
$lang->dev->tableList['tree']             = '模块关系';
$lang->dev->tableList['upgrade']          = '更新';
$lang->dev->tableList['cron']             = '定时任务';
$lang->dev->tableList['datatable']        = '数据表格';
$lang->dev->tableList['block']            = '区块';
$lang->dev->tableList['branch']           = '平台/分支';
$lang->dev->tableList['doccontent']       = '文档内容';
$lang->dev->tableList['storystage']       = '需求阶段';
$lang->dev->tableList['translate']        = '翻译';
$lang->dev->tableList['tutorial']         = '新手教程';
$lang->dev->tableList['suitecase']        = '套件用例';
$lang->dev->tableList['score']            = '积分';
$lang->dev->tableList['entry']            = '应用';
$lang->dev->tableList['webhook']          = 'WebHook';
$lang->dev->tableList['log']              = '接口日志';
$lang->dev->tableList['message']          = '消息';
$lang->dev->tableList['notify']           = '通知';
$lang->dev->tableList['userview']         = '可访问权限';
$lang->dev->tableList['im_chatuser']      = '客户端用户';
$lang->dev->tableList['im_message']       = '客户端消息';
$lang->dev->tableList['translation']      = '翻译';
$lang->dev->tableList['im_messagestatus'] = '客户端状态';

$lang->dev->groupList['my']      = '我的地盘';
$lang->dev->groupList['product'] = $lang->productCommon;
$lang->dev->groupList['project'] = $lang->projectCommon;
$lang->dev->groupList['qa']      = '测试';
$lang->dev->groupList['doc']     = '文档';
$lang->dev->groupList['report']  = '统计';
$lang->dev->groupList['company'] = '组织';
$lang->dev->groupList['repo']    = '代码';
$lang->dev->groupList['api']     = 'API';
$lang->dev->groupList['message'] = '消息';

$lang->dev->endGroupList['admin']  = '后台';
$lang->dev->endGroupList['system'] = '系统';
$lang->dev->endGroupList['other']  = '其他';

==> ZenTaoALM.12.5.3.int.zip: zentaoalm/module/dev/lang/zh-cn.php <==
<?php
$lang->dev->common     = '二次开发';
$lang->dev->api        = 'API';
$lang->dev->db         = '数据库';
$lang->dev->editor     = '编辑器';
$lang->dev->translate  = '翻译';
$lang->dev->dbList     = '数据库';
$lang->dev->moduleList = '模块列表';
$lang->dev->params     = '参数列表';
$lang->dev->type       = '类型';
$lang->dev->desc       = '描述';
$lang->dev->noParams   = '无参数';
$lang->dev->post       = 'POST参数';

$lang->dev->paramRange    = '取值范围：%s';
$lang->dev->paramDate     = '日期格式：YY-mm-dd，如：2019-01-01';
$lang->dev->paramColor    = '颜色格式：#RGB，如：#3da7f5';
$lang->dev->paramMailto   = "填写帐号，多个账号用','分隔。";
$lang->dev->noteEditor    = "编辑器功能因为安全原因被禁用。使用该功能，请到官网下载安装 <a href='https://www.zentao.pm/extension-viewExt-150.html' target='_blank'>扩展编辑器</a> 插件。";
$lang->dev->noteTranslate = "翻译功能因为安全原因被禁用。使用该功能，请到官网下载安装 <a href='https://www.zentao.pm/extension-viewExt-151.html' target='_blank'>翻译</a> 插件。";

$lang->dev->fields = array();
$lang->dev->fields['id']     = '序号';
$lang->dev->fields['name']   = '字段';
$lang->dev->fields['desc']   = '描述';
$lang->dev->fields['type']   = '类型';
$lang->dev->fields['length'] = '长度';
$lang->dev->fields['null']   = '是否可空';

$lang->dev->tableList = array();
$lang->dev->tableList['action']           = '系统日志';
$lang->dev->tableList['bug']              = 'Bug';
$lang->dev->tableList['build']            = '版本';
$lang->dev->tableList['burn']             = '燃尽图';
$lang->dev->tableList['case']             = '测试用例';
$lang->dev->tableList['casestep']         = '用例步骤';
$lang->dev->tableList['company']          = '公司';
$lang->dev->tableList['config']           = '配置';
$lang->dev->tableList['custom']           = '自定义';
$lang->dev->tableList['dept']             = '部门';
$lang->dev->tableList['doc']              = '文档';
$lang->dev->tableList['doclib']           = '文档库';
$lang->dev->tableList['effort']           = '日志';
$lang->dev->tableList['extension']        = '插件';
$lang->dev->tableList['file']             = '附件';
$lang->dev->tableList['group']            = '用户组';
$lang->dev->tableList['grouppriv']        = '组权限';
$lang->dev->tableList['history']          = '操作历史';
$lang->dev->tableList['lang']             = '语言定义';
$lang->dev->tableList['module']           = '模块';
$lang->dev->tableList['product']          = $lang->productCommon;
$lang->dev->tableList['productplan']      = $lang->productCommon . '计划';
$lang->dev->tableList['project']          = $lang->projectCommon;
$lang->dev->tableList['projectproduct']   = $lang->projectCommon . $lang->productCommon;
$lang->dev->tableList['projectstory']     = $lang->projectCommon . $lang->storyCommon;
$lang->dev->tableList['release']          = '发布';
$lang->dev->tableList['story']            = $lang->storyCommon;
$lang->dev->tableList['storyspec']        = "{$lang->storyCommon}描述";
$lang->dev->tableList['task']             = '任务';
$lang->dev->tableList['taskestimate']     = '任务预计';
$lang->dev->tableList['team']             = '团队';
$lang->dev->tableList['testresult']       = '测试结果';
$lang->dev->tableList['testrun']          = '测试执行';
$lang->dev->tableList['testtask']         = '测试单';
$lang->dev->tableList['todo']             = '待办';
$lang->dev->tableList['user']             = '用户';
$lang->dev->tableList['usercontact']      = '用户联系人';
$lang->dev->tableList['usergroup']        = '用户组';
$lang->dev->tableList['userquery']        = '用户查询';
$lang->dev->tableList['usertpl']          = '用户模板';
$lang->dev->tableList['admin']            = '后台管理';
$lang->dev->tableList['api']              = 'API接口';
$lang->dev->tableList['backup']           = '备份';
$lang->dev->tableList['common']           = '公有模块';
$lang->dev->tableList['convert']          = '导入';
$lang->dev->tableList['dev']              = '二次开发';
$lang->dev->tableList['git']              = 'GIT';
$lang->dev->tableList['index']            = '首页';
$lang->dev->tableList['install']          = '安装';
$lang->dev->tableList['mail']             = '邮箱';
$lang->dev->tableList['misc']             = '杂项';
$lang->dev->tableList['my']               = '我的地盘';
$lang->dev->tableList['qa']               = '测试';
$lang->dev->tableList['report']           = '统计';
$lang->dev->tableList['search']           = '搜索';
$lang->dev->tableList['sso']              = '单点登录';
$lang->dev->tableList['svn']              = 'SVN';
$lang->dev->tableList['testcase']         = '测试用例';
$lang->dev->tableList['testreport']       = '测试报告';
$lang->dev->tableList['testsuite']        = '测试套件';
$lang->dev->tableList['caselib']          = '用例库';
$lang->dev->tableList['tree']             = '模块关系';
$lang->dev->tableList['upgrade']          = '更新';
$lang->dev->tableList['cron']             = '定时任务';
$lang->dev->tableList['datatable']        = '数据表格';
$lang->dev->tableList['block']            = '区块';
$lang->dev->tableList['branch']           = '平台/分支';
$lang->dev->tableList['doccontent']       = '文档内容';
$lang->dev->tableList['storystage']       = "{$lang->storyCommon}阶段";
$lang->dev->tableList['tutorial']         = '新手教程';
$lang->dev->tableList['suitecase']        = '套件用例';
$lang->dev->tableList['score']            = '积分';
$lang->dev->tableList['entry']            = '应用';
$lang->dev->tableList['webhook']          = 'WebHook';
$lang->dev->tableList['log']              = '接口日志';
$lang->dev->tableList['message']          = '消息';
$lang->dev->tableList['notify']           = '通知';
$lang->dev->tableList['userview']         = '可访问权限';
$lang->dev->tableList['repo']             = '代码';
$lang->dev->tableList['repohistory']      = '版本历史';
$lang->dev->tableList['repofiles']        = '代码文件';
$lang->dev->tableList['repobranch']       = '代码分支';
$lang->dev->tableList['ci']               = '持续集成';
$lang->dev->tableList['compile']          = '构建';
$lang->dev->tableList['jenkins']          = 'Jenkins';
$lang->dev->tableList['job']              = '构建任务';

$lang->dev->groupList['my']      = '我的地盘';
$lang->dev->groupList['product'] = $lang->productCommon;
$lang->dev->groupList['project'] = $lang->projectCommon;
$lang->dev->groupList['qa']      = '测试';
$lang->dev->groupList['doc']     = '文档';
$lang->dev->groupList['report']  = '统计';
$lang->dev->groupList['company'] = '组织';
$lang->dev->groupList['repo']    = '持续集成';
$lang->dev->groupList['api']     = 'API';
$lang->dev->groupList['message'] = '消息';

$lang->dev->endGroupList['admin']  = '后台';
$lang->dev->endGroupList['system'] = '系统';
$lang->dev->endGroupList['other']  = '其他';
